import java.net.InetAddress;
import java.net.UnknownHostException;


/**
 * A LogEntry provides all information that was logged about a request to a web server.
 */
public class LogEntry {

    private String remoteHost;
    private TimeStamp timeStamp;
    private String request;
    private int status;
    private int size;

    
    public LogEntry(final String remoteHost, final TimeStamp timeStamp, final String request, final int status, final int size) {
        this.remoteHost = remoteHost;
        this.timeStamp = timeStamp;
        this.request = request;
        this.status = status;
        this.size = size;
    }

    public String getRemoteHost() {
        return remoteHost;
    }

    public InetAddress getRemotHostAddress() {
        try {
            return InetAddress.getByName(remoteHost);
        } catch (final UnknownHostException ex) {
            return null;
        }
    }
    
    public TimeStamp getTimeStamp() {
        return timeStamp;
    }
    
    public String getRequest() {
        return request;
    }
    
    public int getStatus() {
        return status;
    }
        
    public int getSize() {
        return size;
    }
    
    public String toString() {
        return remoteHost+" ? ? "+timeStamp+" ["+request+"] "+status+" "+size;
    }
    
}
