import java.util.GregorianCalendar;


/**
 * A TimeStamp represents a point in time (a date and a time).
 */
public class TimeStamp {

    private final GregorianCalendar date;


    public TimeStamp(final GregorianCalendar date) {
        this.date = date;
    }

    /**
     * Returns the year.
     */
    public int getYear() {
        return date.get(GregorianCalendar.YEAR);
    }
    
    /**
     * Returns the month (January is 0).
     */
    public int getMonth() {
        return date.get(GregorianCalendar.MONTH);
    }
    
    /**
     * Returns the day of month (first day is 1).
     */
    public int getDayOfMonth() {
        return date.get(GregorianCalendar.DAY_OF_MONTH);
    }
    
    /**
     * Returns the day of week (Sunday=1 ... Saturday=7).
     */
    public int getDayOfWeek() {
        return date.get(GregorianCalendar.DAY_OF_WEEK);
    }
    
    /**
     * Returns the hour (0...23).
     */
    public int getHour() {
        return date.get(GregorianCalendar.HOUR_OF_DAY);
    }
    
    /**
     * Returns the minute (0...59).
     */
    public int getMinute() {
        return date.get(GregorianCalendar.MINUTE);
    }
    
    /**
     * Returns the second (0...59).
     */
    public int getSecond() {
        return date.get(GregorianCalendar.SECOND);
    }
    
    /**
     * Get a String representation of this TimeStamp.
     */
    public String toString() {
        return String.format("%04d.%02d.%02d %02d:%02d:%02d", getYear(), getMonth()+1, getDayOfMonth(), getHour(), getMinute(), getSecond());
    }
    
}
